@@ -1,5 +1,5 @@
 use super::Pure;
-use crate::{compress::util::get_lhs_ident, mode::Mode};
+use crate::mode::Mode;
 use swc_common::{util::take::Take, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ExprExt, ExprFactory};
@@ -163,7 +163,7 @@ where
                         ..
                     }),
                 ) => {
-                    let var_name = get_lhs_ident(&a_assign.left);
+                    let var_name = a_assign.left.as_ident();
                     let var_name = match var_name {
                         Some(v) => v,
                         None => continue,
